@@ -1,9 +1,9 @@
-;; SKK tutorial (version 3.3 for SKK version 4.20, and later versions.)
-;; Copyright (C) 1991 Masahiko Sato (masahiko@sato.riec.tohoku.ac.jp)
+;; SKK tutorial (version 3.4 for SKK version 5.29, and later versions.)
+;; Copyright (C) 1988, 1992 Masahiko Sato (masahiko@sato.riec.tohoku.ac.jp)
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either versions 1, or (at your option)
+;; the Free Software Foundation; either versions 2, or (at your option)
 ;; any later version.
 
 ;; This program is distributed in the hope that it will be useful
@@ -15,17 +15,21 @@
 ;; along with SKK, see the file COPYING.  If not, write to the Free
 ;; Software Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+;; version 3.4 released 1992.4.12
 ;; version 3.3 released 1991.4.20
 ;; version 3.2 released 1990.4.15
 ;; version 2.2 released 1989.4.15
 
+;; Introduced by W. Matsui (matsui@atr-rd.atr.co.jp), 1991.8.14.
+(defvar skk-tut-directory exec-directory)
+
 (setq j-mode-line-skk nil)
 (setq skk-problem-nos 37)
 
 (defun skk-tutorial ()
   (interactive)
   (let ((inhibit-quit t))
-    (setq skk-features-save features) ;; save featres and restore it later
+    (setq skk-features-save features) ;; save features and restore it later
     (if (featurep 'skk) (setq skk-server-host-save skk-server-host
 			      skk-mode-save skk-mode))
     (load "skk")
@@ -36,14 +40,21 @@
     (if (not (fboundp 'j-save-other-window))
 	(fset 'j-save-other-window (symbol-function 'other-window)))
     (fset 'other-window 'j-other-window)
-    (if (get-buffer " *jisyo*")
+    (if (get-buffer " *skk-jisyo*")
 	(save-excursion
 	  (setq skk-jisyo-save t)
-	  (set-buffer " *jisyo*")
-	  (copy-to-buffer " *save-jisyo*" (point-min) (point-max))))
+	  (set-buffer " *skk-jisyo*")
+	  (copy-to-buffer " *save-skk-jisyo*" (point-min) (point-max))
+	  (erase-buffer)
+	  (set-buffer " *skk-okuri-jisyo*")
+	  (copy-to-buffer " *save-skk-okuri-jisyo*" (point-min) (point-max))
+	  (erase-buffer)
+	  ))
     (set-buffer (get-buffer-create " *skk-tutorial*"))
     (erase-buffer)
-    (insert-file-contents (concat exec-directory "SKK.tut"))
+    ;; Modified by W. Matsui, 1991.8.14.
+    (insert-file-contents
+     (concat (expand-file-name skk-tut-directory) "SKK.tut"))
     (goto-char (point-min))
     (switch-to-buffer (get-buffer-create "**"))
     (erase-buffer)
@@ -68,6 +79,10 @@
     (skk-answer-window)
     (message "")))
 
+(defun j-save-skk-variables ()
+  (setq skk-server-host-save skk-server-host
+	iskk-mode-save skk-mode))
+
 (defun j-skk-mode ()
   (interactive)
   (or (featurep 'skk) (provide 'skk))
@@ -153,16 +168,18 @@
 	    (setq skk-server-host skk-server-host-save
 		  skk-mode skk-mode-save))
 	(setq features skk-features-save)
-	(if (file-exists-p "~/.skk") (load "~/.skk"))
-	(if skk-server-host (j-open-server))
 	(if skk-jisyo-save
 	    (progn
-	      (set-buffer " *save-jisyo*")
-	      (copy-to-buffer " *jisyo*" (point-min) (point-max))
-	      (kill-buffer " *save-jisyo*"))
-	  (set-buffer (get-buffer-create " *jisyo*"))
-	  (erase-buffer)
-	  (insert-file-contents skk-jisyo)))))
+	      (set-buffer " *save-skk-jisyo*")
+	      ;; call skk-mode in this buffer to restore the initial setup
+	      (let ((j-skk-mode-invoked nil))
+		(skk-mode t))
+	      (copy-to-buffer " *skk-jisyo*" (point-min) (point-max))
+	      (kill-buffer " *save-skk-jisyo*")
+	      (set-buffer " *save-skk-okuri-jisyo*")
+	      (copy-to-buffer " *skk-okuri-jisyo*" (point-min) (point-max))
+	      (kill-buffer " *save-skk-okuri-jisyo*")
+	      )))))
 
 (defun skk-answer-window ()
   (interactive)
@@ -276,9 +293,15 @@
 
 (defun skk-use-jisyo (str)
   (save-excursion
-    (set-buffer (get-buffer-create " *jisyo*"))
+    (set-buffer (get-buffer-create " *skk-jisyo*"))
     (erase-buffer)
-    (insert str)))
+    (insert ";; okuri-nasi entries.\n" str)))
+
+(defun skk-use-okuri-jisyo (str)
+  (save-excursion
+    (set-buffer (get-buffer-create " *skk-okuri-jisyo*"))
+    (erase-buffer)
+    (insert ";; okuri-ari entries.\n" str)))
 
 (defun skk-end-of-tutorial ()
   (message "")
